@echo off
echo -----------------------------------
echo --------Download Libraries---------
echo -----------------------------------

echo -----------------------------------
echo ---Setting Environment Variables---
echo -----------------------------------

set thirdpartyGeneration=%1
set buildType=%2
set wxStable=%3

set urlCreatisSource=https://www.creatis.insa-lyon.fr/~davila/creatools_back_site/crea_ThirdParty_Libraries/source/

if %PROCESSOR_ARCHITECTURE%==x86 (
  set ProgramFilesPath_x86=%ProgramFiles%
  echo "Architecture found = x86"
) else (
  set "ProgramFilesPath_x64=%ProgramFiles%"
  set "ProgramFilesPath_x86=%ProgramFiles(x86)%"
  echo "Architecture found = x64"
)

::set vcvarsall="%ProgramFilesPath_x86%\Microsoft Visual Studio 10.0\VC\vcvarsall.bat"

::if not exist %zipPath% set zipPath="%ProgramFilesPath_x64%\7-Zip\7z.exe"
::if not exist %zipPath% (
::  echo ERROR!!! 7Zip has not been found in the system
::  pause
::  exit
::)

::if not exist %vcvarsall% set vcvarsall="%ProgramFilesPath_x64%\Microsoft Visual Studio 10.0\VC\vcvarsall.bat"
::if not exist %vcvarsall% (
::  echo ERROR!!! Visual Studio has not been found in the system
::  pause
::  exit
::)

if not exist %wgetPath% (
  echo ERROR!!! wget has not been found in the system
  exit
)

set installpath=%thirdpartyGeneration%\tpi
set binpath=%thirdpartyGeneration%\tpb
set sourcepath=%thirdpartyGeneration%\tps
set LogFolder=%thirdpartyGeneration%\installLog

set QTFNAME=qt-everywhere-opensource-src-4.8.2.zip

::set ITKFNAME=InsightToolkit-3.20.1.zip
::set ITKFNAME=InsightToolkit-4.12.1.tar
set ITKFNAME=InsightToolkit-5.0.1-patchCreatis.zip

::set WXFNAME=wxWidgets-2.8.12.zip
::set WXVERSION=2.8.12
set WXFNAME=wxWidgets-3.0.4.7z
set WXVERSION=3.0.4

:: set BOOSTFNAME=boost_1_49_0.7z
:: set BOOSTFNAME=boost_1_52_0.7z
::set BOOSTFNAME=boost_1_64_0.7z
set BOOSTFNAME=boost_1_69_0.zip

::set XERCESFNAME=xerces-c-3.1.1.zip
::set XERCESFNAME=xerces-c-3.1.4.zip
set XERCESFNAME=xerces-c-3.2.3.zip

:: set VTKFNAME=vtk-5.10.0.zip
:: set VTKFNAME=VTK-8.1.1-patch_mingw64.7z
set VTKFNAME=VTK-8.1.1-Patch.7z
:: set VTKFNAME=VTK-8.2.0-Patch-TDx.zip

::set GDCMFNAME=gdcm_05_Mai_2011.tar
::set GDCMFNAME=gdcm_11_Oct_2011.tar
::set GDCMFNAME=gdcm_10_Mars_2017-vtk7.tar
set GDCMFNAME=gdcm13_2019_06_17_vtk8.zip

set TTHFNAME=tth_exe.zip
set SQLITEFNAME=sqlite_v3.6.23.1.zip
set JOMFNAME=jom.zip
set DLFCNFNAME=dlfcn-win32-2018-07.7z
set OPENGLMESANAME=opengl-mesa.zip


echo -----------------------------------
echo Environment variables Configuration
echo -----------------------------------
echo ThirdpartyGeneration=%thirdpartyGeneration%
echo BuildType=%buildType%
echo wget=%wgetPath%
echo urlCreatis=%urlCreatisSource%
echo 7zip=%zipPath%
::echo Visual Studio=%vcvarsall%
echo InstallPath=%installpath%
echo BinPath=%binpath%
echo SourcePath=%sourcepath%

echo -----------------------------------
echo ------Downloading Sources----------
echo -----------------------------------

cd %sourcepath%\

if %EEDdownloadQT%==FALSE GOTO SKIPDOWNLOADQT
  %wgetPath% "http://releases.qt-project.org/qt4/source/%QTFNAME%"
  %wgetPath% "http://releases.qt-project.org/jom/%JOMFNAME%"
  echo -----------------------------------
  echo --------------Qt-------------------
  echo -----------------------------------
  call %vcvarsall%
  cd %sourcepath%
  %zipPath% x %sourcepath%\%QTFNAME%
  del %sourcepath%\%QTFNAME%
  echo -----------------------------------
  echo --------------JOM------------------
  echo -----------------------------------
  cd %sourcepath%
  %zipPath% x %sourcepath%\%JOMFNAME% -o*
::  del %sourcepath%\%JOMFNAME%
:SKIPDOWNLOADQT

  
if %EEDdownloadITK%==FALSE GOTO SKIPDOWNLOADITK
  %wgetPath% --no-check-certificate "%urlCreatisSource%/%ITKFNAME%"  
  echo -----------------------------------
  echo -------------ITK-------------------
  echo -----------------------------------
  cd %sourcepath%
  %zipPath% x %ITKFNAME%
::  del %ITKFNAME%
::  del %ITKFNAME%.gz
:SKIPDOWNLOADITK
  
if %EEDdownloadWXWINDOWS%==FALSE GOTO SKIPDOWNLOADWXWINDOWS
::  %wgetPath% "http://downloads.sourceforge.net/project/wxwindows/%WXVERSION%/%WXFNAME%?r=http%3A%2F%2Fwww.wxwidgets.org%2Fdownloads%2F%23latest_dev&ts=1357255370&use_mirror=ufpr"
  %wgetPath% --no-check-certificate  "%urlCreatisSource%/%WXFNAME%"
  echo -----------------------------------
  echo -----------wxWidgets---------------
  echo -----------------------------------
  echo ----------Extracting---------------
  cd %sourcepath%
  %zipPath% x %sourcepath%\%WXFNAME% -owxWidgets_%WXVERSION%
::  del %sourcepath%\%WXFNAME%
:SKIPDOWNLOADWXWINDOWS

if %EEDdownloadBOOST%==FALSE GOTO SKIPDOWNLOADBOOST
:: %wgetPath% "http://downloads.sourceforge.net/project/boost/boost/1.49.0/%BOOSTFNAME%?r=http%3A%2F%2Fsourceforge.net%2Fprojects%2Fboost%2Ffiles%2Fboost%2F1.49.0%2F&ts=1357255694&use_mirror=hivelocity"
::  %wgetPath% "http://downloads.sourceforge.net/project/boost/boost/1.64.0/boost_1_64_0.7z?r=http%3A%2F%2Fsourceforge.net%2Fprojects%2Fboost%2Ffiles%2Fboost%2F1.64.0%2Fboost_1_64_0.7z%2Fdownload&ts=1360058777&use_mirror=ignum"
  %wgetPath% --no-check-certificate  "%urlCreatisSource%/%BOOSTFNAME%"
  echo -----------------------------------
  echo ------------Boost------------------
  echo -----------------------------------
  cd %sourcepath%
  %zipPath% x %sourcepath%\%BOOSTFNAME%
::  del %sourcepath%\%BOOSTFNAME%
:SKIPDOWNLOADBOOST

if %EEDdownloadXERCES%==FALSE GOTO SKIPDOWNLOADXERCES
::  %wgetPath% "http://mirror.ibcp.fr/pub/apache//xerces/c/3/sources/%XERCESFNAME%"
  %wgetPath% --no-check-certificate "%urlCreatisSource%/%XERCESFNAME%"
  echo   %wgetPath% "http://mirror.ibcp.fr/pub/apache//xerces/c/3/sources/%XERCESFNAME%"

::  %wgetPath% --no-check-certificate "https://archive.apache.org/dist/xerces/c/3/sources/%XERCESFNAME%"
  echo -----------------------------------
  echo -------------XERCES----------------
  echo -----------------------------------
  cd %sourcepath%
  %zipPath% x %XERCESFNAME%
::  del %XERCESFNAME%
:SKIPDOWNLOADXERCES

if %EEDdownloadVTK%==FALSE GOTO SKIPDOWNLOADVTK
::  %wgetPath% --no-check-certificate "http://www.vtk.org/files/release/8.1/%VTKFNAME%"
  %wgetPath% --no-check-certificate "%urlCreatisSource%/%VTKFNAME%"
  echo -----------------------------------
  echo -------------VTK-------------------
  echo -----------------------------------
  cd %sourcepath%
  %zipPath% x %sourcepath%\%VTKFNAME%
::  del %sourcepath%\%VTKFNAME%
:SKIPDOWNLOADVTK
  
if %EEDdownloadGDCM%==FALSE GOTO SKIPDOWNLOADGDCM
  %wgetPath% --no-check-certificate "%urlCreatisSource%/%GDCMFNAME%"
  echo -----------------------------------
  echo ------------GDCM ------------------
  echo -----------------------------------
  cd %sourcepath%
  %zipPath% x %GDCMFNAME%
::  del %GDCMFNAME%
::  del %GDCMFNAME%
:SKIPDOWNLOADGDCM
  
if %EEDdownloadTTH%==FALSE GOTO SKIPDOWNLOADTTH
  %wgetPath% "http://hutchinson.belmont.ma.us/tth/tth-noncom/%TTHFNAME%"
  echo -----------------------------------
  echo --------------TTH------------------
  echo -----------------------------------
  cd %sourcepath%
  %zipPath% x %TTHFNAME%
::  del %TTHFNAME%
:SKIPDOWNLOADTTH

if %EEDdownloadSQLite%==FALSE GOTO SKIPDOWNLOADSQLITE
  %wgetPath% --no-check-certificate "%urlCreatisSource%/%SQLITEFNAME%"
  echo ------------------------------------------------
  echo --------------SQLite (creatis)------------------
  echo ------------------------------------------------
  cd %sourcepath%
  %zipPath% x %SQLITEFNAME%
::  del %SQLITEFNAME%
:SKIPDOWNLOADSQLITE


if %EEDdownloadDLFCN%==FALSE GOTO SKIPDOWNLOADDLFCN
  %wgetPath% --no-check-certificate "%urlCreatisSource%/%DLFCNFNAME%"
::  git clone https://github.com/dlfcn-win32/dlfcn-win32.git
  echo ------------------------------------------------
  echo --------------DLFCN (creatis)------------------
  echo ------------------------------------------------
  cd %sourcepath%
  %zipPath% x %DLFCNFNAME%
::  del %DLFCNFNAME%
:SKIPDOWNLOADDLFCN
if %EEDdownloadOPENGLMESA%==FALSE GOTO SKIPDOWNLOADOPENGLMESA
  %wgetPath% --no-check-certificate "%urlCreatisSource%/../../../crea_Developer_Tools/v4/%OPENGLMESANAME%"
  echo ------------------------------------------------
  echo --------------OPENGL MESA (creatis)------------------
  echo ------------------------------------------------
  cd %sourcepath%
  %zipPath% x %OPENGLMESANAME%
::  del %OPENGLMESANAME%
:SKIPDOWNLOADOPENGLMESA



echo -----------------------------------
echo --------Renaming Folders-----------
echo -----------------------------------
cd %sourcepath%
rename qt-everywhere-opensource-src-4.8.2 qt
rename wxWidgets_%WXVERSION% wxWidgets
rename boost_1_69_0 boost
rename InsightToolkit-5.0.1 itk

rename VTK-8.1.1 vtk
:: rename VTK-8.2.0-Patch-TDx vtk

rename gdcm13_2018_05_28_vtk8 gdcm13
rename tth_exe tth
rename xerces-c-3.2.3 xerces
rename sqlite_v3.6.23.1 sqlite

echo -----End of Download Libraries-----
echo -----------------------------------
echo -----------------------------------

exit /B